@@ -9,27 +9,30 @@ from .account import Account
 from .user import User
 from .token import Token
 
-__version__ = "1.1.1"
+__version__ = "1.1.2"
 
 
 class FreedomClient(object):
     """Freedom Robotics API client library. Instantiate this first and access all API functions from within a FreedomClient.
 
-    You can instantiate a `FreedomClient` using either no arguments (in which case credentials are searched for in ~/.freedom_credentials), a `token` and `secret`, or a `username` and `password`.
+    You can instantiate `FreedomClient` using either no arguments (in which case credentials are searched for in ~/.freedom_credentials), a `token` and `secret`, or a `username` and `password`. You can also specify an url or an environment to select which API to use.
 
     Args:
         token (str): API token. Can be a session or user token.
         secret (str): API secret.
         username (str): Username.
         password (str): Password.
+        url (str): API url.
+        env (str): Environment to select API (dev, qa, staging, release).
     """
-    def __init__(self, token=None, secret=None, username=None, password=None, url=None, **api_args):
+    def __init__(self, token=None, secret=None, username=None, password=None, url=None, env=None, **api_args):
         self.api = APIHandler.get_instance(
             url=url,
             token=token,
             secret=secret,
             username=username,
             password=password,
+            env=env,
             **api_args
         )
         assert self.api is not None
