@@ -9,6 +9,7 @@ class User(Entity):
         _id (str): User ID (e-mail address).
         _data (`dict`): User data.
     """
+    pk = 'user'
 
     def __repr__(self):
         return "<User: %s %s %s>" % (
@@ -17,8 +18,9 @@ class User(Entity):
             self._data.get("last_name",  ""),
         )
 
-    def _make_url(self):
-        return "/users/{}".format(self._id)
+    @property
+    def url_base(self):
+        return '/users'
 
     @property
     def first_name(self):
